.. _index:

.. include:: ../README.rst


Installing
==========


Install stable releases of Schematics with ``pip``.

::

  $ pip install schematics

See the :doc:`install` for more detail.


.. include:: toc.rst


Development
===========

We welcome ideas and code.  We ask that you follow some of our guidelines
though.

See the :doc:`development` for more information.


.. include:: community.rst
